'''
EntNav - views.py
Manages XML responses for the location selection widget. 
'''
from Groups.models import GroupCategory, Group, ServiceProperty, GroupServiceProperty, GroupService
from django.http import HttpResponse
from django.template.loader import render_to_string

def GroupCategories(request):
    '''
    Return XML list of Group Categories.
    '''
    groupcategories = GroupCategory.objects.all().order_by('name')
    response = HttpResponse(mimetype='text/xml')
    response.write(render_to_string("entnav-groupcategories", {'groupcategories': groupcategories}))
    return response

def Groups(request, groupcategoryid):
    '''
    Return XML list of Groups within a given category.
    '''
    groups = Group.objects.filter(category = groupcategoryid)
    response = HttpResponse(mimetype='text/xml')
    response.write(render_to_string("entnav-groups", {'groups': groups}))
    return response

def Locations(request, groupid):
    '''
    Return XML list of Locations for a given group.
    '''
    group = Group.objects.get(id = groupid)
    groupservices = GroupService.objects.filter(group=group, service__is_location=True)
    service_titles={}
    for gs in groupservices:
        try:
            sp = ServiceProperty.objects.get(service=gs.service, service_title = True)
            gsp = GroupServiceProperty.objects.get(groupservice=gs, serviceproperty=sp)
            service_titles[gs.id]=gsp.value
        except (ServiceProperty.DoesNotExist, GroupServiceProperty.DoesNotExist):
            pass
    response = HttpResponse(mimetype='text/xml')
    response.write(render_to_string("entnav-locations", {'locations': groupservices, 'service_titles': service_titles}))
    return response
