from django.forms import ModelForm
from django import forms
from LocationWidget import LocationWidget
from DateTimeWidget import DateTimeWidget
from Events.models import EventTag, Event, EventTime

class EventForm(ModelForm):
    '''
    Form for an event. 
    '''
    description = forms.CharField(
        widget = forms.Textarea,
        help_text = Event._meta.get_field('description').help_text)
    
    location_additional = forms.CharField(
        label = Event._meta.get_field('location_additional').verbose_name,
        widget = LocationWidget(),
        required = False,
        help_text = Event._meta.get_field('location_additional').help_text)
    
    tags = forms.ModelMultipleChoiceField(
        EventTag.objects.all(),
        required = False,
        widget = forms.CheckboxSelectMultiple,
        help_text = Event._meta.get_field('tags').help_text)
    
    url = forms.URLField(
        label = Event._meta.get_field('url').verbose_name,
        verify_exists = True,
        required = False)
    
    class Meta:
        model = Event
        fields = ['title', 'description', 'cost', 'location_additional', 'url', 'tags', 'public']
        
class AddTimeForm(ModelForm):
    ''' Add EventTime form. '''
    start = forms.DateTimeField(
        widget=DateTimeWidget(),
        label='Start Time of Event')
        
    finish = forms.DateTimeField(
        widget=DateTimeWidget(),
        label='Finish Time of Event',
        required = False)
    
    class Meta:
        model = EventTime
        fields = ['start', 'finish']
    
    def clean(self):
        cleaned_data = self.cleaned_data
        start = cleaned_data.get("start")
        finish = cleaned_data.get("finish")

        if finish != None and start > finish:
            raise forms.ValidationError("The finish time must be after the start time!")

        # Always return the full collection of cleaned data.
        return cleaned_data
