from django.db import models
from Groups.models import Group, GroupService
from django.utils.encoding import smart_str
from basic.funcs import PidgeException

class EventTag(models.Model):
    ''' 
    A simple string label to attach to an Event.
    '''
    name = models.CharField(max_length=256)
    
    def __unicode__(self):
        return self.name


class Event(models.Model):
    ''' 
    An Event.
    '''

    group = models.ForeignKey(Group)
    
    title = models.CharField(
        max_length=256,
        blank=False,
        help_text="(required)")
    
    description = models.TextField(
        blank=False,
        help_text="Give the potential attendee everything they need to know.")
    
    created = models.DateTimeField(auto_now_add=True)
    last_modified = models.DateTimeField(auto_now=True)
    
    cost = models.CharField(
        "Cost to Attend",
        max_length=256,
        blank=True)
    
    location_additional = models.CharField(
        "Location",
        max_length=512,
        blank=True,
        help_text = "Where this event is happening. ")
    
    public = models.BooleanField(
        "Make Public",
        default=True,
        help_text="Should the event be listed? ")
    
    external_id = models.IntegerField(
        default=-1,
        editable=False)
    
    tags = models.ManyToManyField(
        EventTag,
        blank=True,
        help_text="Select between 1 and 3 that fit your event. ")
    
    url = models.URLField(
        "Website for this Event",
        blank=True,
        verify_exists=True)
    
    interesting = models.BooleanField(default=False)
    
    def __unicode__(self):
        return self.title

class EventTime(models.Model):
    ''' 
    A period of time at which an event happens.
    '''

    event = models.ForeignKey(Event)
    start = models.DateTimeField()
    finish = models.DateTimeField(blank = True, null = True)
    allday = models.BooleanField(default = False)
    
    class EventTimeException(PidgeException): pass
    class Negative(EventTimeException): pass
    
    def __unicode__(self):
        return u'%s - %s' % (self.event.title, self.start)


class Observance(models.Model):
    ''' 
    A label that applies to the whole day.
    e.g. an anniversary or national holiday
    '''

    date = models.DateField()
    title = models.CharField(max_length=100)
    url = models.URLField(blank=True)
    created = models.DateTimeField(auto_now_add=True)
    last_modified = models.DateTimeField(auto_now=True)
    annual = models.BooleanField(default=True, help_text="At same date each year.")
    
    def __unicode__(self):
        return u'%s - %s' % (self.date, self.title)
