'''
Events.tests.models
'''

from Groups.models import Group, GroupCategory
from Events.models import Event, EventTag, EventTime, Observance
from Users.models import User, Reminder
from django.core import mail
from django.test import TestCase

class EventTagTests(TestCase):
    
    def setUp(self):
        self.eventtag = EventTag.objects.create(name="MyTag2")
    
    def test_unicode_name(self):
        ''' Check unicode string rep of EventTag '''
        self.failUnlessEqual(unicode(self.eventtag), "MyTag2")
        
class EventTests(TestCase):
    
    def setUp(self):
        self.category = GroupCategory.objects.create(name = "NewCat", small_name = "NC", all_can_create = True)
        self.group = Group.objects.create(official_name = "My Python", category = self.category)
        self.event = Event.objects.create(group = self.group, title = "Excting New Event", description = "The best thing to have happened recently.")   


    def test_unicode_name(self):
        ''' Check unicode string rep of Event '''
        self.failUnlessEqual(unicode(self.event), "Excting New Event")
        
class EventTimeTests(TestCase):
    
    def setUp(self):
        self.category = GroupCategory.objects.create(name = "NewCat", small_name = "NC", all_can_create = True)
        self.group = Group.objects.create(official_name = "My Python", category = self.category)
        self.event = Event.objects.create(group = self.group, title = "Excting New Event", description = "The best thing to have happened recently.")   
        self.eventtime = EventTime.objects.create(event = self.event, start = "2008-10-30 16:00:00", finish = "2008-10-30 18:00:00")
        self.fergus = User.objects.create(
            firstname="Fergus",
            lastname="Ferrier",
            email="fff21@cam.ac.uk",
            password = "blah",
            membershipstatus="OK",
            activationlinkkey="imokay")
        self.fergus.UpdatePassword("password")

    def test_unicode_name(self):
        ''' Check unicode string rep of EventTime '''
        self.failUnlessEqual(unicode(self.eventtime), "Excting New Event - 2008-10-30 16:00:00")    
    
    def test_event_reminder_send(self):
        ''' Set up a reminder to be sent '''
        Reminder.objects.create(person = self.fergus, event = self.event, assoctype='EML_DY')
        import EmailReminderSender
        self.assertEquals(len(mail.outbox), 1)
        
class ObservanceTests(TestCase):
    
    def setUp(self):
        self.observance = Observance.objects.create(date = "2009-01-01", title = "Nude Ear")
    
    def test_unicode_name(self):
        ''' Check unicode string rep of Observance '''
        self.failUnlessEqual(unicode(self.observance), "2009-01-01 - Nude Ear")    
