from django.forms import ModelForm
from Groups.models import Group, GroupCategory, GroupTag
from django import forms
from LocationWidget import LocationWidget

class GroupForm(ModelForm):
    ''' Form used to change Group details. '''
    # We use model._meta to get the field attributes so no need to repeat
    friendly_name = forms.CharField(label = Group._meta.get_field('friendly_name').verbose_name, required=False, widget=forms.TextInput(attrs={'class':'mp-shorttext'}), help_text = Group._meta.get_field('friendly_name').help_text)
    category = forms.ModelChoiceField(label = Group._meta.get_field('category').verbose_name, queryset = GroupCategory.objects.filter(all_can_create=True), help_text = Group._meta.get_field('category').help_text)
    tags = forms.ModelMultipleChoiceField(GroupTag.objects.all(), label = Group._meta.get_field('tags').verbose_name, required = False, widget=forms.CheckboxSelectMultiple(), help_text = Group._meta.get_field('tags').help_text)

    class Meta:
        model = Group
        fields = ('official_name', 'friendly_name', 'description', 'category', 'tags')


class RegisterGroupForm(GroupForm):
    ''' Form to create Group. '''
    
    def __init__(self, data=None, person=None, *args, **kwargs):
        ''' Extend to Instantiate form.
        Pass in a user. '''
        self.person = person
        super(RegisterGroupForm, self).__init__(data, *args, **kwargs)

    def save(self, *args, **kwargs):
        ''' Extend save to add user as controller '''
        newgroup = super(RegisterGroupForm, self).save(*args, **kwargs)
        
        from Users.models import Membership
        # This user becomes controller and creator
        creassoc = Membership(person = self.person, group = newgroup, assoctype = 'CRE')
        creassoc.save()
        ctlassoc = Membership(person = self.person, group = newgroup, assoctype = 'CTL')
        ctlassoc.save()
        
        return newgroup
        
class GenericPropertyForm(forms.Form):
    ''' Form for a generic ServiceProperty. '''
    value = forms.CharField(max_length=256, required=False)

class LocationPropertyForm(forms.Form):
    ''' Form for a location ServiceProperty. '''
    value = forms.CharField(max_length=256, required=False, widget=LocationWidget)
    
class InviteControllerForm(forms.Form):
    ''' Form used to invite a new controller. '''
    email = forms.EmailField(label="E-Mail Address", help_text="(required)")
    
    class Invalid(Exception): pass

class UploadLogoForm(forms.Form):
    ''' Form used to upload a logo. '''
    image = forms.FileField(label="New logo", help_text="(required)")
    
    class Invalid(Exception): pass