from django.forms import ModelForm, ValidationError
from Email.models import EmailTemplate
from Users.models import User
from django import forms
from django.conf import settings
from models import CommsOfficer

class MailingForm(ModelForm):
    ''' Form for sending a mailing to comms officers '''
    distribution = forms.ChoiceField(
        widget = forms.RadioSelect,
        choices = [('all', 'All Students'),
        ('undergrad', 'Undergraduate Students Only'),
        ('postgrad', 'Postgrad Students Only'),],
        required = True,
        label = "Which class of students does this announcement apply to?",
        initial = 'all'
        
    )

    class Meta:
        model = EmailTemplate
        fields = ('subject', 'body')
    
    def __init__(self, data=None, user = None, *args, **kwargs):
        self.user = user
        super(MailingForm, self).__init__(data, *args, **kwargs)
    
    def save(self, *args, **kwargs):
        # Add other fields before saving
        self.instance.name = self.cleaned_data['subject']
        self.instance.email_from = "thePidge@mypidge.com"
        self.instance.email_from_name = unicode(self.user)
        self.instance.email_reply_to = self.user.email
        self.instance.email_reply_to_name = unicode(self.user)
        
        # Create the emailtemplate
        emailtemplate = super(MailingForm, self).save(*args, **kwargs)
        if self.cleaned_data['distribution'] == "all":
            CommsOfficer.objects.send_all(emailtemplate)
        if self.cleaned_data['distribution'] == "undergrad":
            CommsOfficer.objects.send_undergrad(emailtemplate)
        if self.cleaned_data['distribution'] == "postgrad":
            CommsOfficer.objects.send_postgrad(emailtemplate)
        
        return emailtemplate