from django.db import models
from Groups.models import Group
from Users.models import Person

class CommsOfficerManager(models.Manager):
    ''' Handles logic on sending mailings to CommsOfficers '''
    
    def send(self, template, officers):
        ''' Send email '''
        for entry in officers:
            template.add_recipient(entry.contact, alternate_email = entry.position_email)
        # Don't actually send straight away
        # template.send()
    
    def send_all(self, template):
        ''' Send to all comms officers '''
        officers = CommsOfficer.objects.all()
        self.send(template, officers)

    def send_undergrad(self, template):
        ''' Send to undergrad SU comms officers '''
        officers = CommsOfficer.objects.filter(body_grad = False)
        self.send(template, officers)

    def send_postgrad(self, template):
        ''' Send to postgrad SU comms officers '''
        officers = CommsOfficer.objects.filter(body_grad = True)
        self.send(template, officers)
        

class CommsOfficer(models.Model):
    ''' A comms / publicity officer / secretary of a college student union. '''
    
    objects = CommsOfficerManager()
    
    college = models.ForeignKey(
        Group,
        related_name = "union_comms_officer",
        help_text = "The college that this student union is part of.")
    
    body = models.ForeignKey(
        Group,
        verbose_name = "student union",
        related_name = "comms_officer",
        help_text = "The student union for which this person is an officer.")
    
    body_grad = models.BooleanField(
        "Type of student union",
        default = False,
        help_text = "Is this a Graduate student union?")
    
    position_name = models.CharField(
        "official title",
        max_length = 100,
        default = "relevant officer")
    
    position_email = models.EmailField(
        "position's email address",
        blank = True,
        help_text = "An email address for the position, not the person.")  
    
    contact = models.ForeignKey(
        Person,
        verbose_name = "current officer")
    
    def __unicode__(self):
        return u'%s - %s %s' % (self.contact, self.body, self.position_name)
