'''
Use cases: 
Society manager wants to pass on a message to all students at the University
Society manager wants to advertise an event to all undergrads or postgrads only

Features:
- Prefixes email with Dear X,
- Email supports context data
- Requires Raven login as well as registration
- Can choose individual colleges
- Can send an event already on the Pidge
- Customise the response
- Send at particular time
- Collates messages for individual comms officer.
- Adds an extra line to the end of messages to explain where it came from and why. 
- Handle Clare UCS messages / colleges that don't do this. 
- Preview before sending
- Send User a copy
'''

from basic.funcs import MustLoginMessage
from django.shortcuts import render_to_response
from forms import MailingForm
from Users.models import User

@MustLoginMessage("Please log in to send publicity.")
def SendMailing(request):
    ''' Let the user send a mailing to comms officers '''
    bc = [{'title': 'Send Cambridge Publicity'}]

    user = User.objects.get(id = request.session['userid'])

    flags = {}
    initial = {}

    formdata = None
    if request.method == "POST" and request.POST:
        formdata = request.POST

    mailingform = MailingForm(formdata, user = user)
    
    mailingform.base_fields['body'].label = "The message content."
    
    if formdata:
        if mailingform.is_valid():
            emailtemplate = mailingform.save()
            flags['mailing_sent'] = True

    return render_to_response('publicity-mailing', {'breadcrumb': bc, 'mailingform': mailingform.as_p(), 'flags': flags, 'user': user})

