'''
RavenAuth.tests.views 
'''

from Users.models import User
from django.test import TestCase, Client
from django.core import mail
from django.contrib.sessions.models import Session
from django.core.urlresolvers import reverse


class BasicViews(TestCase):
    def setUp(self):
        # Reqd so that PREPEND_WWW in settings doesn't cause all view tests to fail
        self.host = "www.testhost" 
        self.client = Client(HTTP_HOST = self.host)
        
        self.fergus = User.objects.create(
            firstname="Fergus",
            lastname="Ferrier",
            email="fff21@cam.ac.uk",
            password="password")
        self.fergus.UpdatePassword("password")
        self.fergus.GiveDefaults()
        
        self.fergus = User.objects.create(
            firstname="Blogger",
            lastname="Head",
            email="frf19@cam.ac.uk",
            password="null")
        self.fergus.UpdatePassword("password")
        self.fergus.GiveDefaults()
       
    
    def test_raven(self):
        ''' Page loads and redirects on first run '''
        response = self.client.get(reverse('Raven', args=[""]))
        self.assertEquals(response['Location'].split('?')[0], 'https://raven.cam.ac.uk/auth/authenticate.html')
        
class RavenTests(TestCase):

    def setUp(self):
        self.fergus = User.objects.create(firstname="Fergus", lastname="Ferrier", email="fff21@cam.ac.uk", password="password", membershipstatus="OK", activationlinkkey="imokay")
        self.fergus.UpdatePassword("password")
        response = self.client.post(
            reverse('Users.views.Login', args=[""]),
            {'email': self.fergus.email, 'password': "password"})        
        # Do lots of faffing to set session!
        mysessioncookie = self.client.cookies['sessionid']
        mysessionid = mysessioncookie.value
        mysession = Session.objects.get(pk = mysessionid)
        mysessiondict = mysession.get_decoded()
        mysessiondict['raven-crsid'] = "yyy21"
        Session.objects.save(mysessionid, mysessiondict, "2009-10-10 10:10:10")


    def test_logout(self):
        self.assertEquals(self.client.session['raven-crsid'], "yyy21")
        response = self.client.get(reverse('Logout', args=[""]))
        self.assertEquals(self.client.session.get('raven-crsid'), None)
        