'''
RavenAuth.views - Manage authentication with Raven.
'''
import metapaw.Raven as Raven
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template.loader import render_to_string
from django.conf import settings
from Users.models import User
from Users.views import Login


def DoRaven(request, returnurl, passthru=False):
    ''' Do Raven Authentication
    
    This works by having the user pass several times through this routine. 
    Firstly, the Raven module will redirect them to the Raven server. 
    Then, they interact with the Raven server which then sends them back to us. 
    This second request to our server has details that enable our server to identify and verify the user.
    '''

    if request.session.get('loggedin'):
        return HttpResponseRedirect(returnurl)
    
    thisurl = request.path

    if not returnurl:
        returnurl = '/'
    
    # These global variables are used to keep track of what has to be done
    global ravenrequest
    ravenrequest = request
    
    global ravenredirect
    ravenredirect = None
    
    global ravenresponse
    ravenresponse = HttpResponse()
    
    if passthru:
        class cred(object):
            principal = passthru
    else:
        # We need to tell the Raven object what functions to use for controlling the process
        
        # It seems here we're overwriting functions of the Raven object? 
        # Reference for function that gets the WLS value Raven passes back with the user
        Raven.wls_response = wls_response
        # Reference for function that sets the URL to redirect the user to
        Raven.redirect = raven_redirect
        # Instance of class that enables persistent storage of session data
        Raven.persistenceMethod = InsecureCookiesPersistenceMethod()
        
        UCam = Raven.Service('https://raven.cam.ac.uk/auth/authenticate.html', {'2': settings.PIDGE_RAVEN_KEY} )
        
        try:
            cred = Raven.authenticate(UCam,
                thisURL = 'http://' + request.META['SERVER_NAME'] + thisurl,
                message = 'For login',
                targetDescription = settings.PIDGE_FRIENDLY_NAME,
                pageParameters = '/',
                maximumClockSkew = 5000,
            )
            # Do we need to redirect the user?
            if ravenredirect:
                return HttpResponseRedirect(ravenredirect)


        # TODO What kind of exceptions?
        except Exception, e:
            # TODO Update this rather user-unfriendly template
            return render_to_response('ravenauth-error', {'text': 'Error'})
    
    # If we get here, authentication has been successful

    # Session their CRSID, and follow login procedure
    request.session['raven-crsid'] = cred.principal
    return Login(request, returnurl)
            
def wls_response():
    ''' Get querystring parameter that Raven returns 
    Used by metapaw
    '''
    try:
        resp = ravenrequest.GET['WLS-Response']
    except(KeyError):
        resp = None
    return resp

def raven_redirect(url):
    ''' Called by metapaw to Redirect user '''
    global ravenredirect
    ravenredirect=url

class InsecureCookiesPersistenceMethod:
    ''' Used by metapaw to keep track of the user ''' 
    
    def __init__(self):
        self.cookie_name = 'metapaw-Raven-Authentication'
    
    def get(self):
        global ravenrequest
        try:
            return ravenrequest.COOKIES[self.cookie_name]
        except KeyError:
            return None
    
    def set(self, wls_response):
        global ravenresponse
        ravenresponse.set_cookie(key=self.cookie_name, value=wls_response)
    
    def delete(self):
        try:
            ravenresponse.delete_cookie(self.cookie_name)
        except KeyError:
            pass
