'''
Start.tests.models
'''

from Users.models import User
from Start.models import StartLink
from django.core import mail
from django.test import TestCase

class StartLinkTestCase(TestCase):
    
    def setUp(self):
        self.fergus = User.objects.create(firstname="Fergus", lastname="Ferrier", email="fff21@cam.ac.uk", password="password")
        self.fergus.UpdatePassword("password")
    
    def test_unicode_name(self):
        ''' Check unicode string rep of StartLink '''
        self.mylink = StartLink.objects.create(url = "http://www.facebook.com", name="My Link", owner=self.fergus)
        self.failUnlessEqual(unicode(self.mylink), "My Link")
        
class StartLinkManagerTestCase(TestCase):

    def setUp(self):
        self.fergus = User.objects.create(firstname="Fergus", lastname="Ferrier", email="fff21@cam.ac.uk", password="password")
        self.fergus.UpdatePassword("password")
    
    # Add
    
    def test_add(self):
        ''' Add a link > user owns, user has one more link '''
        startcount = self.fergus.links.count()
        StartLink.objects.Add(self.fergus, "This Link", "http://www.this.com")
        thatlink = StartLink.objects.get(url="http://www.this.com")
        self.assertEqual(thatlink.owner, self.fergus)
        self.assertEqual(self.fergus.links.count(), startcount + 1)
        
        
    def test_add_bad_url(self):
        ''' Add a link minus http:// '''
        StartLink.objects.Add(self.fergus, "This Link", "www.another.com")
        thatlink = StartLink.objects.get(name="This Link")
        self.assertEqual(thatlink.url, "http://www.another.com")
        
    def test_add_secure_url(self):
        ''' Try a link with https:// '''
        StartLink.objects.Add(self.fergus, "This Link", "https://www.another.com")
        thatlink = StartLink.objects.get(name="This Link")
        self.assertEqual(thatlink.url, "https://www.another.com")
        
    def test_add_again(self):
        ''' Cannot add same link twice '''
        StartLink.objects.Add(self.fergus, "This Link", "http://www.this.com")
        startcount = self.fergus.links.count()
        StartLink.objects.Add(self.fergus, "OMG SAMe URL!", "http://www.this.com")
        self.assertEqual(self.fergus.links.count(), startcount)
        
    # Get Pidge Links
    