#!/usr/bin/python
"""
activationreminder.py
Send email reminders to activate your account. 
"""

from django.conf import settings
from datetime import datetime, timedelta
from Users.models import User

def SendReminders():
    """
    Send the emails for reminders that are due - 48 hours after registration without activation.
    """
    from django.template.loader import render_to_string

    two_days = 60 * 60 * 24 * 2
    
    two_days_ago = datetime.now() - timedelta(seconds = two_days)
    
    users = User.objects.filter(
        membershipstatus = "EP",
        registered__lt = two_days_ago,
        activation_reminder__isnull = True).distinct()
    
    for user in users:
        recipient = recipient = ["\"%s\" <%s>" % (unicode(user), user.email)]
        sender = "%s <%s>" % (settings.PIDGE_FRIENDLY_NAME, settings.PIDGE_EMAIL)
        subject = "%s, Please Activate Your Account" % user.firstname
        
        message = render_to_string('users-email-activation-reminder', { 'user':  user, 'server_name': settings.SERVER_NAME, 'linkkey': user.activationlinkkey })
        
        from django.core.mail import EmailMessage
        email = EmailMessage(subject=subject, from_email=sender, body=message, to=recipient)
        email.send()
        
        user.activation_reminder = datetime.now()
        user.save()