'''
Users.tests.activationreminder

'''
from Users.models import User
from django.test import TestCase, Client
from django.core import mail
from django.core.urlresolvers import reverse
from Users.activationreminder import SendReminders

class ReminderTests(TestCase):
    def setUp(self):
        # Reqd so that PREPEND_WWW in settings doesn't cause all view tests to fail
        self.host = "www.testhost" 
        self.client = Client(HTTP_HOST = self.host)
        
        self.fergus = User.objects.create(
            firstname="Fergus",
            lastname="Ferrier",
            email="fff21@cam.ac.uk",
            password="password",
            membershipstatus="EP",
            activationlinkkey="imokay")
        self.fergus.UpdatePassword(self.fergus.password)
        
        self.usertwo = User.objects.create(
            firstname="E",
            lastname="Parkinson",
            email="eric.parkinson@hotmail.com",
            password="pleaselogmein",
            membershipstatus="OK",
            activationlinkkey="heythere")
        self.usertwo.UpdatePassword(self.usertwo.password)

    # Email reminder two days later
    
    def test_reminder(self):
        ''' Users after 48 hours not activated get a reminder '''
        self.fergus.registered = "2008-10-10 10:10:10"
        self.fergus.save()
        
        SendReminders()
        self.assertEquals(len(mail.outbox), 1)
        self.fergus = User.objects.get(pk = self.fergus.pk)
        self.assert_(self.fergus.activation_reminder)
        
    
    def test_reminder_once(self):
        ''' Activation reminders are only sent once '''
        self.fergus.activation_reminder = "2008-10-10 10:10:10"
        self.fergus.save()
        
        SendReminders()
        self.assertEquals(len(mail.outbox), 0)
    
    def test_reminder_bad(self):
        ''' Users not in EP get no reminder '''
        self.usertwo.registered = "2008-10-10 10:10:10"
        self.usertwo.save()
        
        SendReminders()
        self.assertEquals(len(mail.outbox), 0)

    
