'''
Users.tests.doctests

>>> from Users.models import User, Reminder, Membership, MembershipClaim
>>> from Events.models import Event
>>> from Groups.models import Group, GroupCategory

We start with only one user - the Pidge.

>>> allusers = User.objects.all()
>>> allusers
[<User: The Pigeon>]

Let's add a real user with basic details. 

>>> fergus = User(firstname='Fergus', lastname='Ferrier', crsid='fff21', email='fff21@cam.ac.uk')
>>> fergus.save()

String representation of the object is first name and then last name.

>>> unicode(fergus)
u'Fergus Ferrier'

And we now have two users:

>>> allusers = User.objects.all()
>>> allusers
[<User: The Pigeon>, <User: Fergus Ferrier>]

Fergus forgot he'd already registered...

>>> fergusagain = User(firstname='Fergus', lastname='Ferrier', crsid='fff21', email='fff21@cam.ac.uk')
>>> fergusagain.save()
Traceback (most recent call last):
    ...
DuplicateEmail...

Now we need a group for Fergus to join. What about MyPidge?

>>> societycat = GroupCategory.objects.get(name='Society')
>>> mypidgegroup = Group(official_name='MyPidge', category=societycat)
>>> mypidgegroup.save()
>>> fergusjoins = Membership(user=fergus, group=mypidgegroup, assoctype='INT')
>>> fergusjoins.save()
>>> Membership.objects.all()
[<Membership: Fergus Ferrier MyPidge>]

And he'd like a reminder by email one day before an exciting event coming up.

>>> mypidgeevent = Event(group=mypidgegroup, title="Exciting MyPidge Meet", description="The most exciting thing you will ever do with your life. Ever.", cost="Nothing.")
>>> mypidgeevent.save()
>>> eventreminder = Reminder(user=fergus, event=mypidgeevent, assoctype='EML_DY')
>>> eventreminder.save()
>>> Reminder.objects.all()
[<Reminder: Fergus Ferrier EML_DY>]

Fergus is the owner of MyPidge, but he doesn't have access to the admin settings on the web site. 

>>> fergusclaim = MembershipClaim(user=fergus, group=mypidgegroup, justification="I set it up, check on the web site: www.mypidge.com")
>>> fergusclaim.save()
>>> MembershipClaim.objects.all()
[<MembershipClaim: Fergus Ferrier MyPidge>]
'''