'''
Users.views - things what Users can do. 
'''
from django import forms
from django.shortcuts import render_to_response
from django.template.loader import render_to_string
from django.template import Context, loader
from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect, HttpResponse
from django.conf import settings
from Users.models import User, Membership, CambridgeMember, Person
from Events.models import EventTag
from Start.views import generateDefaultSettingsString, generateSettingsString
from Start.models import StartLink
from Groups.models import Group, GroupServiceProperty
from urllib import quote
from basic.funcs import PidgeException, MustLogin, MustLoginMessage
import string
import time
from datetime import datetime
from Users.forms import ChangeDetailsForm, ChangePasswordForm, RegisterForm, ResetPasswordForm, DoResetPasswordForm, CambridgeRegisterForm

def Logout(request, returnurl):
    ''' Perform logout. '''
    if request.session.get('loggedin'):
        del request.session['loggedin']
    if request.session.get('raven-crsid'):
        del request.session['raven-crsid']
    if not returnurl:
        returnurl = '/'
    response = HttpResponseRedirect(returnurl)
    
    response.set_cookie('spsettings', quote(generateDefaultSettingsString()))
    return response

def Login(request, returnurl):
    ''' Login '''
    bc = [{'title': 'Login'}]
    
    crsid = ""
    if not returnurl: returnurl = '/'
    if request.session.get('raven-crsid'):
        crsid = request.session['raven-crsid']
    if request.session.get('loggedin'): 
        return HttpResponseRedirect(returnurl)
    
    flags = {}
    
    lf = ""

    if request.method == 'POST':
        lf = LoginForm(request.POST)
    else:
        lf = LoginForm()
    
    if (request.method == 'POST') or crsid:
        user = ""
        
        try:
            if crsid:
                # Check CRSID in CambridgeMember table and then look up User
                user = CambridgeMember.objects.get(crsid = crsid)
                user = User.objects.get(pk = user.pk)
                user.Authenticate()
            else:
                if not lf.is_valid():
                    raise LoginForm.Invalid
                user = User.objects.get(email = lf.cleaned_data['email'])
                user.Authenticate(password = lf.cleaned_data['password'])

        except LoginForm.Invalid:
            pass
            
        except (KeyError, User.DetailsError, User.DoesNotExist, CambridgeMember.DoesNotExist):
            if crsid:
                return HttpResponseRedirect(reverse('Users.views.RegisterDetails'))
            flags['details_error'] = True

        except User.NotActivated:
            request.session['activationuserid'] = user.id
            flags['not_activated'] = True

        except User.Deactivated:
            flags['deactivated'] = True
            
        else:
            return LoginUser(user, request, returnurl)
    
    if request.session.get('raven-crsid'):
        # User has authenticated with Raven, and not registered
        return HttpResponseRedirect(reverse('Users.views.RegisterDetails'))
    
    if 'notactivated' in request.GET:
        flags['not_activated'] = True
    if 'deactivated' in request.GET:
        flags['deactivated']  = True
    if 'alreadyactive' in request.GET:
        flags['already_active']  = True
    
    if request.session.get('login_message'):
        flags['login_message'] = request.session['login_message']
        del request.session['login_message']
    
    return render_to_response('users-login', {'loginform': lf.as_p(), 'breadcrumb': bc, 'returnurl': returnurl, 'flags': flags})

class LoginForm(forms.Form):
    ''' Form for login '''
    email = forms.EmailField()
    password = forms.CharField(max_length=32, widget=forms.PasswordInput, required=False)
    
    class Invalid(Exception): pass


def LoginUser(user, request, returnurl):
    ''' Do admin for logging in a user '''
    
    request.session['userid'] = user.id
    request.session['loggedin'] = True

    response = HttpResponseRedirect(returnurl)
    startlinks = user.links.all()
    
    # The quote call is required so that python (or maybe it's django) doesn't weirdify the xml
    response.set_cookie('spsettings', quote(generateSettingsString(User.objects.get(pk = request.session['userid']))))
    return response
    
def RegisterDetails(request, returnurl=None):
    ''' Show form for User registration '''
    if not returnurl: returnurl = '/'
    bc = [{'title': 'Login', 'url': reverse('Users.views.Login', args=[returnurl])},
        {'title': 'Register'}]
        

    if request.session.get('loggedin'): return HttpResponseRedirect(returnurl)
    
    crsid = None
    flags = {}
    initial = {}
    caminitial = {}
    person = None
    cammember = None
    
    if 'raven-crsid' in request.session:
        crsid = request.session['raven-crsid']
        initial['email'] = crsid + '@cam.ac.uk'
        
        # Do we already know anything about the user?
        try:
            cammember = CambridgeMember.objects.get(crsid = crsid)
            person = Person.objects.get(pk = cammember.pk)
            userinstance = User(**person.as_dict())
            
            # Member of a college? 
            usercolleges = person.groups.filter(category__small_name = 'COL')
            if usercolleges.count() == 1:
                caminitial['college'] = usercolleges[0].id
                
        except CambridgeMember.DoesNotExist:
            cammember = None

    formdata = None
    if request.method == "POST" and request.POST:
        formdata = request.POST

    # If person already exists, pass the Userform a User instance with person's details        
    if cammember:
        
        userform = RegisterForm(
            formdata,
            crsid = crsid,
            initial = initial,
            instance = userinstance)
        
        cambridgeform = CambridgeRegisterForm(
            formdata,
            crsid = crsid,
            initial = caminitial,
            instance = cammember)
    else:
        userform = RegisterForm(formdata, crsid = crsid, initial = initial)
        cambridgeform = CambridgeRegisterForm(formdata, crsid = crsid, initial = caminitial)

    if formdata:
        if userform.is_valid() and cambridgeform.is_valid():
            
            newuser, activate = userform.save()
            cambridgeform.pk = newuser.pk
            cambridgeform.save()
            # Do this after saving cambridgeform so they get a link to their college
            newuser.GiveDefaults()
            
            if activate:
                return HttpResponseRedirect(reverse('Users.views.RegisterEmailSent'))
            else:
                SendWelcomeEmail(newuser)
                return LoginUser(newuser, request, reverse('Users.views.ActivationSuccess'))

    if crsid:
        userform.base_fields['email'].help_text = "(required) If you leave this as your @cam.ac.uk address you will not need to confirm your email address. "
        userform.base_fields['password_one'].help_text = "(required) Please choose a password that you can use at %s, in case there's a problem with logging in with Raven. It would be a good idea to choose a password that is not the same as your Raven password." % settings.PIDGE_FRIENDLY_NAME
    
    return render_to_response('users-register-details', {'breadcrumb': bc, 'crsid': crsid, 'userform': userform.as_p(), 'cambridgeform': cambridgeform.as_p(), 'flags': flags})


def ResendActivation(request):
    ''' Send User activation email again! '''
    
    class NoActivationID(Exception): pass
    
    try:
        if not request.session.has_key('activationuserid'):
            raise NoActivationID
        user = User.objects.get(id = request.session['activationuserid'])
        user.SendActivationEmail()
        return RegisterEmailSent(request)
    except (NoActivationID, User.ActivationNotPending):
        return HttpResponseRedirect(reverse('Users.views.Login', args=[""]))

def RegisterEmailSent(request):
    ''' Confirm activation email sent. '''
    bc = [{'title': 'Login', 'url': reverse('Users.views.Login', args=[""])}, {'title': 'Activation Email Sent'}]
    return render_to_response('users-register-email-sent', {'breadcrumb': bc})


def RegisterActivate(request, linkkey):
    ''' Try activating an account. '''
    
    if linkkey:
        try:
            u = User.objects.Activate(linkkey)
        except User.InvalidKey:
            pass
        except User.AlreadyActive:
            return HttpResponseRedirect(reverse('Users.views.Login', args=[""]) +  '?alreadyactive')
        except User.ActivationNotPending:
            pass
        else:
            SendWelcomeEmail(u)
            return LoginUser(u, request, reverse('Users.views.ActivationSuccess'))
            
    return HttpResponseRedirect(reverse('Users.views.ActivationFailure'))

def ActivationSuccess(request):
    ''' Confirm account activation. '''
    bc = [{'title': 'Account Activated'}]
    return render_to_response('users-activate-success', {'breadcrumb': bc})

def ActivationFailure(request):
    ''' Notify account activation failure. '''
    bc = [{'title': 'Account Activation Failed'}]
    return render_to_response('users-activate-failure', {'breadcrumb': bc})

@MustLoginMessage("Please log in to access your account details.")
def Account(request):
    ''' Show account options. '''
    bc = [{'title': 'Account'}]
    return render_to_response('users-account', {'breadcrumb': bc})

@MustLoginMessage("Please log in to change your password.")
def ChangePassword(request):
    ''' Show change password form. '''
    bc = [{'title': 'Account', 'url': reverse('Users.views.Account')}, {'title': 'Change Password'}]
    
    user = User.objects.get(id = request.session['userid'])
    
    flags = {}
    
    if request.method=="POST":
        changepasswordform = ChangePasswordForm(request.POST, instance = user)
        
        if changepasswordform.is_valid():

            changepasswordform.save()
            flags['password_updated'] = True
            
    else:
        changepasswordform = ChangePasswordForm()

    return render_to_response('users-change-password', {'breadcrumb': bc, 'changepasswordform': changepasswordform, 'flags': flags})

@MustLoginMessage("Please log in to update your account details.")
def ChangeDetails(request):
    ''' Show form to change user details '''
    bc = [{'title': 'Account', 'url': reverse('Users.views.Account')},
        {'title': 'Change Name or E-Mail Address'}]
    
    r = HttpResponse()
        
    flags = {}
    user = User.objects.get(id = request.session['userid'])

    if request.method == "POST":
        changedetailsform = ChangeDetailsForm(request.POST, instance=user)
        if changedetailsform.is_valid():
            changedetailsform.save()
            r.set_cookie('spsettings', quote(generateSettingsString(user)))
            flags['details_updated'] = True
    else:
        changedetailsform = ChangeDetailsForm(instance=user)

    return render_to_response('users-change-details', {'breadcrumb': bc, 'changedetailsform': changedetailsform, 'flags': flags})


def ResetPassword(request):
    ''' Show reset password form. '''
    
    flags = {}
    
    if 'loggedin' in request.session:
        return HttpResponseRedirect('/')
    
    if request.method == "POST":
        resetpasswordform = ResetPasswordForm(request.POST)
        if resetpasswordform.is_valid():
            try:
                user = User.objects.get(email = resetpasswordform.cleaned_data['email'])
                resetkey = user.SetResetKey()
                SendResetPasswordEmail(user, resetkey)
                flags['password_reset'] = True
            except User.DoesNotExist:
                # Even if we couldn't find the user, we can't let them know about the email addresses in our system
                flags['password_reset'] = True
    else:
        resetpasswordform = ResetPasswordForm()

    bc = [
        {'title': 'Login', 'url': reverse('Users.views.Login', args=[""])},
        {'title': 'Reset Password'}
        ]
    return render_to_response('users-reset-password', {'breadcrumb': bc, 'resetpasswordform': resetpasswordform, 'flags': flags})

def DoResetPassword(request, passwordresetkey):
    ''' Enable a user to choose a new password '''
    
    if 'loggedin' in request.session:
        return HttpResponseRedirect('/')
    user = None
    if passwordresetkey:
        try:
            user = User.objects.get(password_reset_key = passwordresetkey)
        except User.DoesNotExist:
            pass
    
    resetform = ""
    if request.method == "POST":        
        resetform = DoResetPasswordForm(request.POST)
        if resetform.is_valid():
            # Reset user's password and log them in
            user.UpdatePassword(resetform.cleaned_data['new_password']) 
            user.password_reset_key = ""
            user.save()
            return LoginUser(user, request, reverse('Users.views.DonePasswordReset'))
    else:
        resetform = DoResetPasswordForm()

    bc = [
        {'title': 'Login', 'url': reverse('Users.views.Login', args=[""])},
        {'title': 'Reset Password'}
        ]
    return render_to_response('users-do-reset-password', {'breadcrumb': bc, 'resetform': resetform, 'user': user})


def DonePasswordReset(request):
    ''' Show confirmation of password reset '''
    bc = [
        {'title': 'Login', 'url': reverse('Users.views.Login', args=[""])},
        {'title': 'Reset Password'}
        ]
    return render_to_response('users-password-reset-done', {'breadcrumb': bc})    

def SendResetPasswordEmail(user, passwordkey):
    ''' Send new password email to user. '''
    from django.template.loader import render_to_string    
    
    recipient = ["\"%s\" <%s>" % (unicode(user), user.email)]
    sender = "%s <%s>" % (settings.PIDGE_FRIENDLY_NAME, settings.PIDGE_EMAIL)
    subject = "%s, Reset Your Password Now" % (user.firstname)
    
    message = render_to_string('users-email-password-reset', { 'user':  user, 'server_name': settings.SERVER_NAME, 'passwordkey': passwordkey })
    
    from basic.funcs import SendEmail
    SendEmail(subject=subject, sender=sender, message=message, to=recipient)
    
def SendWelcomeEmail(user):
    ''' A welcome email after registration and activation. '''
    from django.template.loader import render_to_string
    
    recipient = ["\"%s\" <%s>" % (unicode(user), user.email)]
    sender = "%s <%s>" % (settings.PIDGE_FRIENDLY_NAME, settings.PIDGE_EMAIL)
    subject = "%s, Percy Says Hello!" % (user.firstname)

    message = render_to_string('users-email-welcome', { 'user':  user, 'server_name': settings.SERVER_NAME })

    from basic.funcs import SendEmail
    SendEmail(subject=subject, sender=sender, message=message, to=recipient)
