'''
views.py - Views that wouldn't go elsewhere
'''
from django.http import HttpResponseRedirect, HttpResponse
from django.views.decorators.cache import cache_control
from django.shortcuts import render_to_response
from django.template.loader import render_to_string
from django import forms
from datetime import datetime
from urllib import quote, urlopen
from urlparse import urlparse
from django.core.urlresolvers import reverse
from django.conf import settings

def About(request):
    ''' Return the 'About Us' page. '''
    return render_to_response("basic-about", {'breadcrumb': [{'title': 'About ' + settings.PIDGE_FRIENDLY_NAME}]})

def GetInvolved(request):
    ''' Show the Get Involved in the project page '''
    return render_to_response("basic-get-involved", {'breadcrumb': [{'title': 'Get Involved!'}]})

def FeedbackThanks(request):
    ''' Send the 'thanks for your feedback' page. '''
    sender = request.session['email_used']
    return render_to_response("basic-feedback-thanks", {'breadcrumb': [{'title': 'Ta!'}], 'sender': sender})
    
def Feedback(request):
    ''' Show the feedback form. '''
    if request.method == 'POST':
        form = FeedbackForm(request.POST)
        if form.is_valid():
            subject = form.cleaned_data['subject']
            message = form.cleaned_data['message']
            sender = form.cleaned_data['sender']
            cc_myself = form.cleaned_data['cc_myself']
            
            recipients = [settings.PIDGE_EMAIL]
            
            if cc_myself:
                recipients.append(sender)
                
            from django.core.mail import send_mail
            send_mail(subject, message, sender, recipients)
            
            request.session['email_used'] = sender
            return HttpResponseRedirect(reverse('basic.views.FeedbackThanks')) 
    else:
        from Users.models import User
        if request.session.get('loggedin'):
            user = User.objects.get(id = request.session['userid'])
            form = FeedbackForm(initial={'sender': user.email})
        else:
            form = FeedbackForm()
    
    return render_to_response("basic-feedback", {'breadcrumb': [{'title': 'Send %s Feedback' % settings.PIDGE_FRIENDLY_NAME}], 'form': form})

    
class FeedbackForm(forms.Form):
    '''
    The basic feedback form. 
    '''
    sender = forms.EmailField(label="Your Email")
    subject = forms.CharField(max_length=100, label="Message Subject")
    message = forms.CharField(min_length=20, widget=forms.Textarea, label="Message")
    cc_myself = forms.BooleanField(required=False, label="Send me a Copy of the Message?")
