'''
urls.py - URL structure for installation.
'''
from django.conf.urls.defaults import *
from django.contrib import admin
from django.conf import settings

# Automatically find admin site settings.
admin.autodiscover()

import os
docroot = os.getcwd()

urlpatterns = patterns('',
    # Basic
    (r'^About/$', 'basic.views.About'),
    (r'^Get-Involved/$', 'basic.views.GetInvolved'),
    (r'^Feedback/$', 'basic.views.Feedback'),
    (r'^Feedback/Thanks/$', 'basic.views.FeedbackThanks'),

    # Users
    (r'^Login/Reset-Password/$', 'Users.views.ResetPassword'),
    (r'^Login/Reset/Done/$', 'Users.views.DonePasswordReset'),
    (r'^Login/Reset/([a-zA-Z0-9]*)/$', 'Users.views.DoResetPassword'),

    (r'^Login/(.*)$', 'Users.views.Login'),
    url(r'^Logout/(.*)$', 'Users.views.Logout', name="Logout"),
    url(r'^Raven/(.*)$', 'RavenAuth.views.DoRaven', name="Raven"),
    (r'^Register/Raven/(.*)$', 'RavenAuth.views.DoRaven'),
    (r'^Register/Details/$', 'Users.views.RegisterDetails'),
    (r'^Resend-Activation/$', 'Users.views.ResendActivation'),
    (r'^Register-Email-Sent/$', 'Users.views.RegisterEmailSent'),
    (r'^Activate-Account/(.*)/$', 'Users.views.RegisterActivate'),
    (r'^Activate-Success/$', 'Users.views.ActivationSuccess'),
    (r'^Activate-Failure/$', 'Users.views.ActivationFailure'),

    (r'^Account/$', 'Users.views.Account'),
    (r'^Account/Change-Password/$', 'Users.views.ChangePassword'),
    (r'^Account/Change-Details/$', 'Users.views.ChangeDetails'),
    
    
    # Online Desktop
    url(r'^/?$', 'Start.views.StartPage', name="homepage"),
    (r'^Homepage/$', 'Start.views.StartPage'),
    (r'^Start/Customise/$', 'Start.views.Customise'),
    (r'^Start/Customise-Search/$', 'Start.views.CustomiseSearch'),
    (r'^Start/Add-Link/([0-9]*)/(.*)$', 'Start.views.AddGroupServiceLink'),
    (r'^Start/Add-Link/$', 'Start.views.AddLink'),
    (r'^Start/Delete-Link/(?P<linkid>\d+)/$', 'Start.views.DeleteLink'),
    (r'^Start/Get-Events-XML/$', 'Start.views.GetStartPageEvents'),

    (r'^get-search-data/$', 'Start.views.StartPageSearchDataXML'),    
    (r'^get-start-settings/$', 'Start.views.StartPageSettingsXML'),
    (r'^start-settings-js/$', 'Start.views.StartPageSettingsJS'),
    (r'^get-flag-status/$', 'Start.views.GetFlagStatus'),
    (r'^Get-Observances/$', 'Events.views.GetObservance'),
    
    
    # Events
    (r'^Event/Add/$', 'Events.views.Add'),
    (r'^Event/Add/(.*)/Details/$', 'Events.views.AddToGroup'),
    (r'^Event/Add/(.*)/$', 'Events.views.AddOrClone'),
    (r'^Event/([0-9]*)/Add-Time/Added/$', 'Events.views.NowAddTime'),
    url(r'^Event/([0-9]*)/Add-Time/$', 'Events.views.AddTime'),
    (r'^Event/([0-9]*)/Delete-Time/(.*)/$', 'Events.views.DeleteTime'),
    (r'^Event/([0-9]*)/Set-Reminders/$', 'Events.views.SetReminders'),
    (r'^Event/([0-9]*)/Edit/$', 'Events.views.EditEvent'),
    (r'^Event/([0-9]*)/$', 'Events.views.ViewEvent'),
    
    (r'^Events/$', 'Events.views.All'),
    
    # Groups
    (r'^Groups/$', 'Groups.views.Overview'),
    (r'^Groups/All/$', 'Groups.views.All'),
    (r'^Groups/Invitation/(.*)/Accept/$', 'Groups.views.AcceptInvitation'),
    (r'^Groups/Invitation/(.*)/Reject/$', 'Groups.views.RejectInvitation'),
    (r'^Groups/Invitation/(.*)/$', 'Groups.views.ViewInvitation'),
    (r'^Groups/Get-Service-Properties/(.*)/$', 'Groups.views.GetServiceProperties'),

    (r'^Group/Register-Success/(.*)/$', 'Groups.views.RegisterGroupSuccess'),
    (r'^Group/Register/$', 'Groups.views.RegisterGroup'),

    (r'^Group/([0-9]*)/$', 'Groups.views.ViewGroup'),
    (r'^Group/([0-9]*)/Claim-Control/$', 'Groups.views.ClaimControl'),    
    (r'^Group/([0-9]*)/Manage/Upload-Logo/$', 'Groups.views.UploadLogo'),
    (r'^Group/([0-9]*)/Manage/Edit-Services/Add/([0-9]*)/$', 'Groups.views.AddService'),
    (r'^Group/([0-9]*)/Manage/Edit-Services/(.*)/Edit/$', 'Groups.views.EditService'),
    (r'^Group/([0-9]*)/Manage/Edit-Services/(.*)/Delete/$', 'Groups.views.DeleteService'),
    (r'^Group/([0-9]*)/Manage/Edit-Services/$', 'Groups.views.EditServices'),
    (r'^Group/([0-9]*)/Manage/Revoke-Control/([0-9]*)/$', 'Groups.views.RevokeControl'),
    (r'^Group/([0-9]*)/Manage/Cancel-Invitation/([0-9]*)/$', 'Groups.views.CancelInvitation'),
    (r'^Group/([0-9]*)/Manage/Change-Details/$', 'Groups.views.ChangeDetails'),
    (r'^Group/([0-9]*)/Manage/$', 'Groups.views.Manage'),  
    
    # Random
    (r'^Email/Preview/([0-9]*)/$', 'Email.views.Preview'),
    
    (r'^EntNav/GroupCategories/$', 'EntNav.views.GroupCategories'),
    (r'^EntNav/Groups/([0-9]*)/$', 'EntNav.views.Groups'),
    (r'^EntNav/Locations/([0-9]*)/$', 'EntNav.views.Locations'),
    
    (r'^Locations/Show-Location/(.*)/(.*)/$', 'Locations.views.ShowLocation'),
    (r'^Locations/Pick-Location/(.*)/(.*)/(.*)/$', 'Locations.views.PickLocation'),
    
    (r'^Discuss/$', 'Discuss.views.AllConversations'),
    (r'^Discuss/([0-9]*)/$', 'Discuss.views.OneConversation'),
    
    (r'^Pocket/$', 'Pocket.views.Pocket'),
   
)

urlpatterns += patterns('django.views.generic.simple',
    (r'^Events/[0-9]{4}-[A-Za-z]*-[0-9]{1,2}/$', 'redirect_to', {'url': None}),
)

if settings.DEBUG:
    urlpatterns += patterns('',
        (r'^resources/(?P<path>.*)$', 'django.views.static.serve', {'document_root': docroot+'/../Resources/'}),
        (r'^images/(?P<path>.*)$', 'django.views.static.serve', {'document_root': docroot+'/../Images/'}),
    )

urlpatterns += patterns('', 
    (r'^Publicity/', include('Publicity.urls')),
    (r'^admin/(.*)', admin.site.root),
)
